OC.L10N.register(
    "deck",
    {
    "Personal" : "شخصي",
    "copy" : "کاپي",
    "Cancel" : "پرېښول",
    "Details" : "معلومات",
    "Tags" : "نښکې",
    "Can edit" : "سمون راوستی شي",
    "Delete" : "ړنګول",
    "Comments" : "تبصرې",
    "Modified" : "د بدلون نېټه",
    "Save" : "ساتل",
    "Shared with you" : "تاسې سره شريک شوي",
    "Today" : "نن"
},
"nplurals=2; plural=(n != 1);");
